#
# spec file for package klp-build
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
Name:           klp-build
Version:        0~20240731.edfe0bf
Release:        1.1
Summary:        The kernel livepatching creation tool
License:        GPL-2.0-only
URL:            https://github.com/SUSE/klp-build
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  python3-setuptools
Requires:       python3-GitPython
Requires:       python3-Mako
Requires:       python3-MarkupSafe
Requires:       python3-cached-property
Requires:       python3-lxml
Requires:       python3-natsort
Requires:       python3-osc-tiny
Requires:       python3-requests
BuildArch:      noarch

%description
The kernel livepatching creation tool.

%prep
%autosetup -p1

%build
%python3_build

%install
%python3_install
rm -rf %{buildroot}/%{python_sitelib}/scripts/
# Lets install the script to bindir so we can call it
# {python_sitelib}/scripts is not specific enough
cp scripts/run-kgr-test.sh %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_mandir}/man1
cp klp-build.1 %{buildroot}%{_mandir}/man1/
%fdupes  %{buildroot}

%files
%license LICENSE
%doc README.md
%{_bindir}/klp-build
%{python_sitelib}/klpbuild
%{python_sitelib}/klp_build-0.0.1-py3.11.egg-info/
%{_bindir}/run-kgr-test.sh
%{_mandir}/man1/klp-build.1%{?ext_man}

%changelog
* Thu Aug  1 2024 mvetter@suse.com
- Update to version 0~20240731.edfe0bf:
  * Add new test for CVE-2021-47402
  * test.sh: Simplify call to setup_extract_count
  * klpbuild: Copy the .config from the right place
  * templ: Add spaces between KLP_RELOC_SYMBOL macro arguments
* Mon Jul 29 2024 mvetter@suse.com
- Update to version 0~20240725.cc0513f:
  * ksrc.py: Check CVE passed in get-patches
  * extractor: lock the same src directory on which architecture the script is running on
  * Add support for tests files in directories
  * extractor: Add filelocking support for srcdir
* Wed Jul 24 2024 mvetter@suse.com
- Update to version 0~20240722.3c379d8:
  * tests: Fixed one issue on clang-extract
  * tests: Add test.sh to check for known working extraction for CE
  * templ: Fix case of IBT + upstream kernel module with dashes on its name
  * run-kgr-test.sh: Check in more directories for VMs
  * templ.py: Return empty string when IBT and CE
  * extractor: Enable upstream extraction to apply patches
  * templ.py: Replace dash by underscore when using fname on functions
  * ce: Use -DCE_LATE_EXTERNALIZE by default
  * ibs.py: Stop downloading kernel-default-extra
  * ccp: Drop workarounds for different codestreams
  * config: Fix get_sdir to always point to x86_64
  * templ: Add IBT support for ccp
  * extractor: Propagate needs_ibt to extractor backends
  * ccp: Check KLP_CONVERT on fun_exts
  * Change get_cs_boot_file to target odir instead of arch/boot dir
  * templ: Add 15.6 codestream to fixes header
  * extractor: Use IBT for 15.6 onwards
  * setup: Remove s390x check since all codestreams are now supported
  * setup: Show kernel version when file is not found
  * extractor: Do not catch a specific error when running ccp/ce
  * ccp: Remove more options that ccp doesn't understand
  * extractor: Adapt the regex for SLE 15-SP6 cases
  * extractor: Show more info when we can't get the command line
* Tue Jul  2 2024 mvetter@suse.com
- Update to version 0~20240701.f72b4a1:
  * config: Show kernel version when configuration entries diverge
  * Add man page for klp-build
  * ksrc: Remove MIME-Version string from upstream commit subject
- Install man page
* Fri Jun 28 2024 mvetter@suse.com
- Update to version 0~20240627.48ed241:
  * ksrc.py: Add --tags to git fetch
  * Adding support to SLE15-SP6
  * config.py: Dump kernel version and arch when a module is not supported
  * templ.py: Fix Kbuild file generation
* Mon Jun 24 2024 mvetter@suse.com
- Update to version 0~20240622.445505a:
  * config: Add architecture of the duplicated symbol warning
  * config.py: Show kernle version when a duplicate symbol was found
* Mon Jun 24 2024 Michael Vetter <mvetter@suse.com>
- Install run-kgr-test.sh to bindir
- Run fdupes
* Thu Jun 20 2024 Michael Vetter <mvetter@suse.com>
- Initial package of klp-build git 9aa77a for openSUSE
